<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddCmsBlocks extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this->table('cms_block_type', ['id' => false, 'primary_key' => ['cms_block_type_id']])
             ->addColumn('cms_block_type_id', 'integer', ['identity' => 'enable', 'signed' => false])
             ->addColumn('cms_block_type_template', 'string')
             ->create();

        $this->table('cms_block_type_nom', ['id' => false, 'primary_key' => ['cms_block_type_nom_id']])
             ->addColumn('cms_block_type_nom_id', 'integer', ['signed' => false, 'identity' => 'enable'])
             ->addColumn('cms_block_type_id', 'integer', ['signed' => false])
             ->addColumn('langue_id', 'integer', ['signed' => false, 'default' => 1])
             ->addColumn('cms_block_type_nom_nom', 'string')
             ->addForeignKey('cms_block_type_id', 'cms_block_type', 'cms_block_type_id', ['delete' => 'CASCADE', 'update' => 'CASCADE'])
             ->addForeignKey('langue_id', 'langue', 'langue_id', ['delete' => 'RESTRICT', 'update' => 'CASCADE'])
             ->addIndex(['cms_block_type_id', 'langue_id'], ['unique' => true])
             ->create();

        $this->table('cms_block', ['id' => false, 'primary_key' => ['cms_block_id']])
             ->addColumn('cms_block_id', 'integer', ['identity' => 'enable', 'signed' => false])
             ->addColumn('cms_page_id', 'integer', ['signed' => false, 'null' => true])
             ->addColumn('cms_block_rang', 'integer', ['null' => false])
             ->addColumn('cms_block_type_id', 'integer', ['signed' => false, 'null' => true])
             ->addColumn('cms_block_width', 'integer')
             ->addColumn('cms_block_date_ajout', 'datetime', ['default' => '0000-00-00 00:00:00'])
             ->addColumn('cms_block_date_modif', 'datetime', ['default' => '0000-00-00 00:00:00'])
             ->addColumn('cms_block_statut_id', 'integer', ['default' => 1, 'limit' => MysqlAdapter::INT_TINY])
             ->addForeignKey('cms_page_id', 'cms_page', 'cms_page_id', ['delete' => 'SET NULL', 'update' => 'CASCADE'])
             ->addForeignKey('cms_block_type_id', 'cms_block_type', 'cms_block_type_id', ['delete' => 'SET NULL', 'update' => 'CASCADE'])
             ->addIndex(['cms_block_rang'])
             ->addIndex(['cms_page_id'])
             ->addIndex(['cms_block_statut'])
             ->create();

        $this->table('cms_block_nom', ['id' => false, 'primary_key' => ['cms_block_nom_id']])
             ->addColumn('cms_block_nom_id', 'integer', ['identity' => 'enable', 'signed' => false])
             ->addColumn('cms_block_id', 'integer', ['signed' => false])
             ->addColumn('langue_id', 'integer', ['signed' => false])
             ->addColumn('cms_block_nom_nom', 'string')
             ->addColumn('cms_block_nom_title', 'string', ['null' => false])
             ->addColumn('cms_block_nom_image', 'string', ['null' => false])
             ->addColumn('cms_block_nom_image_alt', 'string', ['null' => false])
             ->addColumn('cms_block_nom_link_label', 'string', ['null' => false])
             ->addColumn('cms_block_nom_link_url', 'string', ['null' => false])
             ->addColumn('cms_block_nom_content', 'string', ['null' => false])
             ->addForeignKey('cms_block_id', 'cms_block', 'cms_block_id', ['delete' => 'CASCADE', 'update' => 'CASCADE'])
             ->addForeignKey('langue_id', 'langue', 'langue_id', ['delete' => 'RESTRICT', 'update' => 'CASCADE'])
             ->addIndex(['cms_block_id', 'langue_id'], ['unique' => true])
             ->create();
    }
}
