<?php

use Phinx\Db\Adapter\MysqlAdapter;
use Phinx\Migration\AbstractMigration;

class DynamizeCmsPageType extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this->table('cms_page_type', ['id' => false, 'primary_key' => ['cms_page_type_id']])
             ->addColumn('cms_page_type_id', 'integer', ['identity' => 'enable', 'signed' => false])
             ->addColumn('cms_page_type_rang', 'integer')
             ->addColumn('cms_page_type_statut_id', 'integer', ['default' => 1, 'limit' => MysqlAdapter::INT_TINY])
             ->addIndex(['cms_page_type_rang'])
             ->addIndex(['cms_page_type_status'])
             ->create();

        $this->table('cms_page_type_nom', ['id' => false, 'primary_key' => ['cms_page_type_nom_id']])
             ->addColumn('cms_page_type_nom_id', 'integer', ['identity' => 'enable', 'signed' => false])
             ->addColumn('cms_page_type_id', 'integer', ['signed' => false])
             ->addColumn('langue_id', 'integer', ['signed' => false])
             ->addColumn('cms_page_type_nom_nom', 'string')
             ->addForeignKey('cms_page_type_id', 'cms_page_type', 'cms_page_type_id', ['delete' => 'CASCADE', 'update' => 'CASCADE'])
             ->addForeignKey('langue_id', 'langue', 'langue_id', ['delete' => 'RESTRICT', 'update' => 'CASCADE'])
             ->addIndex(['cms_page_type_id', 'langue_id'], ['unique' => true])
             ->create();

        $dataPageType = [
            [
                'cms_page_type_id'     => 1,
                'cms_page_type_rang'   => 10,
                'cms_page_type_status' => 1
            ],
            [
                'cms_page_type_id'     => 2,
                'cms_page_type_rang'   => 20,
                'cms_page_type_status' => 1
            ]
        ];

        $this->table('cms_page_type')->insert($dataPageType)->update();

        $dataPageTypeNom = [
            [
                'cms_page_type_id'      => 1,
                'langue_id'             => 1,
                'cms_page_type_nom_nom' => 'Standard'
            ],
            [
                'cms_page_type_id'      => 2,
                'langue_id'             => 1,
                'cms_page_type_nom_nom' => 'Blocs'
            ]
        ];

        $this->table('cms_page_type_nom')->insert($dataPageTypeNom)->update();

        $this->table('cms_page')
             ->removeColumn('cms_page_type')
             ->addColumn('cms_page_type_id', 'integer', ['signed' => false, 'default' => 1])
             ->addForeignKey('cms_page_type_id', 'cms_page_type', 'cms_page_type_id', ['delete' => 'RESTRICT', 'update' => 'CASCADE'])
             ->update();
    }
}
