<?php

namespace Controller;

use Breadcrumb;
use Cms;
use CmsBlock;
use DediException;
use Efs\Logo;
use SmartyException;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

// TODO : to remove => use router SF
use Link;

/**
 * Class CmsController
 * @package Controller
 *
 * @Route("")
 */
class CmsController extends Controller
{
    /**
     * @var Cms
     */
    private $cmsRepository;

    /**
     * @var CmsBlock
     */
    private $cmsBlockRepository;

    /**
     * @var Breadcrumb
     */
    private $breadcrumbGenerator;

    /**
     * CmsController constructor.
     */
    public function __construct(Request $request)
    {
        parent::__construct($request);

        $this->cmsRepository       = new Cms();
        $this->cmsBlockRepository  = new CmsBlock();
        $this->breadcrumbGenerator = Breadcrumb::getInstance();
    }


    /**
     * @Route(
     *      path         = "/p-{page_nom_url}.html",
     *      name         = "page",
     *      requirements = { "page_nom_url" = "[a-zA-Z0-9-_]+" }
     * )
     *
     * @return mixed|Response
     * @throws DediException
     * @throws SmartyException
     */
    public function show()
    {
        $pageNomUrl = $this->request->get('page_nom_url');
        $cmsPage    = $this->cmsRepository->getOne(['page_nom_url' => $pageNomUrl]);

        return $this->getResponse($cmsPage);
    }

    /**
     * @Route(
     *      path         = "/preview-cms/{id}",
     *      name         = "preview-cms",
     *      requirements = { "id" = "[0-9]+" }
     * )
     *
     * @return mixed
     * @throws DediException
     * @throws SmartyException
     */
    public function preview_cms()
    {
        $id = $this->request->get('id');

        // On vérifie que l'admin est bien connecté au BO, d'où l'utilisation de la variable $_SESSION au lieu de l'objet Session
        if (empty($_SESSION['connexion']) || $_SESSION['connexion']['actif_id'] != 1) {
            return (new ErrorController($this->request))->error_404();
        }

        $cmsPage = $this->cmsRepository->getOne(['cms_page_id' => $id, 'all' => true]);

        return $this->getResponse($cmsPage);
    }

    /**
     * @param array $cmsPage
     * @return mixed|Response
     * @throws SmartyException
     */
    private function getResponse($cmsPage = array())
    {
        if (empty($cmsPage)) {
            return (new ErrorController($this->request))->error_404();
        }

        // Fil d'arianne
        $this->breadcrumbGenerator->add($cmsPage['page_nom_nom'], $this->generateUrl('page', array('page_nom_url' => $cmsPage['page_nom_url'])));
        //-- Fil d'arianne

        $this->template->assign('cmsPage', $cmsPage);

        // Recupération des Blocs
        if ($cmsPage['cms_page_type_id'] == Cms::TYPE_BLOCK) {
            $cmsBlocks = $this->cmsBlockRepository->get(['cms_page_id' => $cmsPage['cms_page_id']]);
            $this->template->assign('cmsBlocks', $cmsBlocks);
        }
        //-- Recupération des Blocs

        $templateExists = $this->template->templateExists($cmsPage['cms_page_type_template']);

        if ($templateExists === false) {
            return (new ErrorController($this->request))->error_404();
        }

        return $this->render($cmsPage['cms_page_type_template']);
    }
}