<?php

use Symfony\Component\Routing\Router as RouterSF;
use Symfony\Component\Routing\RequestContext;
use Symfony\Component\Config\FileLocator;

use Symfony\Component\Routing\Loader\AnnotationDirectoryLoader;
use Annotation\AnnotationClassLoader;
use Doctrine\Common\Annotations\AnnotationReader;
use Doctrine\Common\Annotations\CachedReader;

/**
 * Class Router
 */
class Router
{
    /**
     * @var \Symfony\Component\Routing\Router
     */
    protected $router;

    /**
     * @var \Annotation\AnnotationClassLoader
     */
    protected $annotationClassLoader;

    /**
     * @var \Symfony\Component\Routing\Loader\AnnotationDirectoryLoader
     */
    protected $annotationDirectoryLoader;

    /**
     * constructeur
     */
    public function __construct()
    {
        $locator = new FileLocator(array(__DIR__ . '/../..'));
        $requestUri = (!empty($_SERVER['REQUEST_URI'])) ? $_SERVER['REQUEST_URI'] : '';
        $requestContext = new RequestContext($requestUri);

        $domaine = getenv('APP_URL') ? getenv('APP_URL') : Boutique::getInstance()->domaine;
        $requestContext->setHost($domaine);
        $requestContext->setBaseUrl('');
        if (empty($requestContext->getScheme())) {
            $requestContext->setScheme('http');
        }

        // $cache = new ApcCache();
        $cache = new \Doctrine\Common\Cache\ArrayCache();

        $reader = new CachedReader(
            new AnnotationReader(),
            $cache,
            $debug = true
        );

        $this->annotationClassLoader = new AnnotationClassLoader($reader);
        $this->annotationDirectoryLoader = new AnnotationDirectoryLoader($locator, $this->annotationClassLoader);

        $cacheDir = SITE_DIR . 'storage' . DS . 'php' . DS . 'router';

        if (is_dir($cacheDir) == false) {
            if (!mkdir($cacheDir, 0775, true) && !is_dir($cacheDir)) {
                throw new \RuntimeException(sprintf('Directory "%s" was not created', $cacheDir));
            }
            chmod($cacheDir, 0775);
        }

        $options = array();
        if (getenv('APP_CACHE')) {
            $options['cache_dir'] = $cacheDir;
        }

        $this->router = new RouterSF(
            $this->annotationDirectoryLoader,
            'src/Dedi/Controller',
            $options,
            $requestContext
        );
    }

    /**
     * retourne le Router
     *
     * @return \Symfony\Component\Routing\Router
     */
    public function getRouter()
    {
        return $this->router;
    }

    /**
     * @return \Annotation\AnnotationClassLoader
     */
    public function getAnnotationClassLoader()
    {
        return $this->annotationClassLoader;
    }

    /**
     * @return \Symfony\Component\Routing\Loader\AnnotationDirectoryLoader
     */
    public function getAnnotationDirectoryLoader()
    {
        return $this->annotationDirectoryLoader;
    }
}